==> qtjambi-remoteobjects-5.15.16-sources.jar: io/qt/remoteobjects/QRemoteObjectSettingsStore.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QRemoteObjectSettingsStore</code></p>
 */
public class QRemoteObjectSettingsStore extends io.qt.remoteobjects.QRemoteObjectAbstractPersistedStore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectSettingsStore.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectSettingsStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectSettingsStore() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code>QRemoteObjectSettingsStore::<wbr>QRemoteObjectSettingsStore(QObject*)</code></p>
     */
    public QRemoteObjectSettingsStore(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectSettingsStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QRemoteObjectAbstractPersistedStore::<wbr>restoreProperties(QString,<wbr>QByteArray)</code></p>
     */
    @QtUninvokable
    public java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig){
        return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
    }
    
    @QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <code>QRemoteObjectAbstractPersistedStore::<wbr>saveProperties(QString,<wbr>QByteArray,<wbr>QVariantList)</code></p>
     */
    @QtUninvokable
    public void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values){
        saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
    }
    
    @QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectSettingsStore instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-5.15.20-sources.jar: io/qt/remoteobjects/QRemoteObjectSettingsStore.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QRemoteObjectSettingsStore</code></p>
 */
public class QRemoteObjectSettingsStore extends io.qt.remoteobjects.QRemoteObjectAbstractPersistedStore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectSettingsStore.class);
    
    
    /**
     * <p>See <code>QRemoteObjectSettingsStore::<wbr/>QRemoteObjectSettingsStore(QObject*)</code></p>
     */
    public QRemoteObjectSettingsStore(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectSettingsStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QRemoteObjectAbstractPersistedStore::<wbr/>restoreProperties(QString,<wbr/>QByteArray)</code></p>
     */
    @QtUninvokable
    @Override
    public java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig){
        return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
    }
    
    @QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <code>QRemoteObjectAbstractPersistedStore::<wbr/>saveProperties(QString,<wbr/>QByteArray,<wbr/>QVariantList)</code></p>
     */
    @QtUninvokable
    @Override
    public void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values){
        saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
    }
    
    @QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectSettingsStore instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectSettingsStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectSettingsStore() {
        this((io.qt.core.QObject)null);
    }
}
